<p align="center">
    <img width="200" src="https://cdn.jsdelivr.net/gh/szj2ys/Qomolangma/Qomolangma/logo.png"/>
</p>

<h3 align="center">
    <p>Awesome NLP framework you are waiting for ✨</p>
</h3>


<p align="center">
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://badge.fury.io/py/Qomolangma.svg" alt="Version"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://img.shields.io/pypi/l/Qomolangma.svg?color=orange" alt="License"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://static.pepy.tech/badge/Qomolangma?color=blue" alt="pypi total downloads"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://img.shields.io/pypi/dm/Qomolangma?color=blue" alt="pypi downloads"/>
    </a>
    <a href="https://python.org/pypi/Qomolangma">
        <img src="https://img.shields.io/github/last-commit/szj2ys/Qomolangma?color=blue" alt="GitHub last commit"/>
    </a>
    <a href="https://github.com/szj2ys/Qomolangma">
        <img src="https://visitor-badge.glitch.me/badge?page_id=szj2ys.Qomolangma" alt="Visitors"/>
    </a>
    <a href="https://github.com/szj2ys/Qomolangma">
        <img src="https://img.shields.io/github/stars/szj2ys/Qomolangma?style=social" alt="Stars"/>
    </a>
</p>

> Qomolangma based on tensorflow 2

# Installation
```shell
pip install Qomolangma
```
you may want to checkout the version
```shell
qomolangma version
```
Haha, `Qomolangma` is now on your environment, having fun with it, enjoy ...


## REFERENCES
- [logly](https://www.logoly.pro/)
- [Kashgari](https://github.com/BrikerMan/Kashgari/)






